/* state-switch version 0.2.4 */
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
        typeof define === 'function' && define.amd ? define(['exports'], factory) :
            (factory((global.window = {})));
}(this, (function (exports) {
    'use strict';
    var version = "0.2.4";
    /**
     *
     * Wechaty: Wechat for Bot. and for human who talk to bot/robot
     *
     * Class StateSwitch
     * Licenst: Apache-2.0
     * https://github.com/zixia/state-switcher
     *
     * Helper Class for Manage State Change
     */
    var VERSION = version;
    var StateSwitch = /** @class */ (function () {
        function StateSwitch(_name, logInstance) {
            if (_name === void 0) { _name = 'Lock'; }
            this._name = _name;
            if (logInstance) {
                this.setLog(logInstance); // init log, should be a Brolog or Npmlog instance
            }
            else {
                this.setLog(null);
            }
            this.log.silly('StateSwitch', 'constructor(%s)', _name);
            this._on = false;
            this._pending = false;
        }
        StateSwitch.prototype.version = function () {
            return VERSION;
        };
        StateSwitch.prototype.setLog = function (logInstance) {
            if (logInstance) {
                this.log = logInstance;
            }
            else {
                this.log = {
                    silly: function () {
                        var args = [];
                        for (var _i = 0; _i < arguments.length; _i++) {
                            args[_i] = arguments[_i];
                        }
                    },
                    verbose: function () {
                        var args = [];
                        for (var _i = 0; _i < arguments.length; _i++) {
                            args[_i] = arguments[_i];
                        }
                    },
                    warn: function () {
                        var args = [];
                        for (var _i = 0; _i < arguments.length; _i++) {
                            args[_i] = arguments[_i];
                        }
                    },
                    error: function () {
                        var args = [];
                        for (var _i = 0; _i < arguments.length; _i++) {
                            args[_i] = arguments[_i];
                        }
                    },
                };
            }
        };
        /**
         * set/get ON state
         */
        StateSwitch.prototype.on = function (state) {
            if (state) {
                this.log.verbose('StateSwitch', '<%s> on(%s) <- (%s)', this._name, state, this.on());
                this._on = true;
                this._pending = (state === 'pending');
                return;
            }
            var on = this._on
                ? this._pending ? 'pending' : true
                : false;
            this.log.silly('StateSwitch', '<%s> on() is %s', this._name, on);
            return on;
        };
        /**
         * set/get OFF state
         */
        StateSwitch.prototype.off = function (state) {
            if (state) {
                this.log.verbose('StateSwitch', '<%s> off(%s) <- (%s)', this._name, state, this.off());
                this._on = false;
                this._pending = (state === 'pending');
                return;
            }
            var off = !this._on
                ? this._pending ? 'pending' : true
                : false;
            this.log.silly('StateSwitch', '<%s> off() is %s', this._name, off);
            return off;
        };
        /**
         * does the state is not stable(in process)?
         */
        StateSwitch.prototype.pending = function () {
            this.log.silly('StateSwitch', '<%s> pending() is %s', this._name, this._pending);
            return this._pending;
        };
        /**
         * get the client name
         */
        StateSwitch.prototype.name = function () {
            return this._name;
        };
        return StateSwitch;
    }());
    exports.VERSION = VERSION;
    exports.StateSwitch = StateSwitch;
    exports['default'] = StateSwitch;
    Object.defineProperty(exports, '__esModule', { value: true });
})));
/* https://github.com/zixia */
//# sourceMappingURL=state-switch.es6.umd.js.map
